SteveKing wrote:
>Just a small issue (typo) in the patch:
>trust_permanantly should be
>trust_permanently
>
>(or is my english totally wrong here? I'm not
>so sure but as I read it it just didn't "feel" right).
>
>
Good spotting, Stefan! This is what copy-paste and a small font can do
you you... :-)
The following patch fixes all occurrences. The patch is build tested
only. I hope the condensed log message format below is OK. If not, just
let me know and I'll write a more verbose one.
/Tobias
Log message:
* subversion/clients/cmdline/prompt.c
* subversion/include/svn_auth.h
* subversion/libsvn_client/auth.c
* subversion/libsvn_ra_dav/session.c
Correct typo: trust_permanantly in the svn_auth_cred_server_ssl_t
struct should be trust_permanently.
Index: subversion/libsvn_client/auth.c
===================================================================
--- subversion/libsvn_client/auth.c (revision 7135)
+++ subversion/libsvn_client/auth.c (working copy)
@@ -529,7 +529,7 @@
if (!failures)
{
svn_auth_cred_server_ssl_t *creds = apr_pcalloc (pool, sizeof(*creds));
- creds->trust_permanantly = FALSE; /* No need to save it again... */
+ creds->trust_permanently = FALSE; /* No need to save it again... */
*credentials = creds;
}
Index: subversion/clients/cmdline/prompt.c
===================================================================
--- subversion/clients/cmdline/prompt.c (revision 7135)
+++ subversion/clients/cmdline/prompt.c (working copy)
@@ -243,13 +243,13 @@
if (choice && (choice[0] == 't' || choice[0] == 'T'))
{
*cred_p = apr_pcalloc (pool, sizeof (**cred_p));
- (*cred_p)->trust_permanantly = FALSE;
+ (*cred_p)->trust_permanently = FALSE;
}
else if (allow_perm_accept &&
choice && (choice[0] == 'p' || choice[0] == 'P'))
{
*cred_p = apr_pcalloc (pool, sizeof (**cred_p));
- (*cred_p)->trust_permanantly = TRUE;
+ (*cred_p)->trust_permanently = TRUE;
}
else
{
Index: subversion/libsvn_ra_dav/session.c
===================================================================
--- subversion/libsvn_ra_dav/session.c (revision 7135)
+++ subversion/libsvn_ra_dav/session.c (working copy)
@@ -162,7 +162,7 @@
else
{
server_creds = creds;
- if (server_creds->trust_permanantly)
+ if (server_creds->trust_permanently)
{
error = svn_auth_save_credentials(state, pool);
if (error)
---------------------------------------------------------------------
To unsubscribe, e-mail: dev-unsubscribe@subversion.tigris.org
For additional commands, e-mail: dev-help@subversion.tigris.org
Received on Mon Sep 22 20:52:19 2003
Index: subversion/include/svn_auth.h
===================================================================
--- subversion/include/svn_auth.h (revision 7135)
+++ subversion/include/svn_auth.h (working copy)
@@ -190,13 +190,13 @@
/** SSL server verification.
*
* If @a trust_permanantly is set to true by the provider, the
* certificate will be trusted permanently.
*/
#define SVN_AUTH_CRED_SERVER_SSL "svn.ssl.server"
typedef struct
{
- svn_boolean_t trust_permanantly;
+ svn_boolean_t trust_permanently;
} svn_auth_cred_server_ssl_t;
@@ -190,13 +190,13 @@
/** SSL server verification.
*
- * If @a trust_permanantly is set to true by the provider, the
+ * If @a trust_permanently is set to true by the provider, the
* certificate will be trusted permanently.
*/